USE MATH

----------------------------------------------------------------------------------------	
-- MODELO DE LA TURBINA EOLICA: 
-- 7000W por linea, un total de 21000W en tres fases
-- Altura de la Turbina: 30m
----------------------------------------------------------------------------------------
-- Fecha de Actualizacion: 16/04/2012

--******************************************************************************
--                        COMPONENTE DE LA TURBINA 
--******************************************************************************

COMPONENT TurbinaVientoNew
	"Modelo de turbina elica"


PORTS

---------------------------------------------------------------------------- 	
-- Entradas: Ve, Teref , Betaref
----------------------------------------------------------------------------
	
		IN  WindVeSource  			WindVeSourceb 		
		IN  WTCPuertos  			   WTCPuertosb
	
---------------------------------------------------------------------------
--Salida: wt
----------------------------------------------------------------------------
		
		OUT WTPuertos						WTPuertosb
		OUT PotPuertos                PotPuertosb
		
           	
DATA

-- Constantes

   REAL denso=1.226					 "Densidad del aire (kg/m3)"

-- Datos de la Turbina

	REAL R=4.5							"Radio de la palas de la turbina (m)"  
   REAL np=18							"Numero de polos del generador"
   REAL Ls=0.074						"Inductancia del generador (H)"
   REAL Rs=5.2                   "Resistencia del estator (ohm)"
   REAL phi=0.1                  "Flujo magnetico (Wb = Kg m2 s-2 A-1) "
   REAL Fr=0                     "Fuerza de friccion (Kg.m2/seg)"   -- 2.79
	REAL Tservo=1.5               "Constante de tiempo para el actuador de calaje (s)"
	REAL Jt=156.9493					"Momento de Inercia (Kg.m^2)"
	REAL idref=0						"Corriente de referencia del eje d (A)"
	REAL kp=9.6							"Constante del controlador de corriente PI"
	REAL ki=1334.4						"Constante del controlador de corriente PI"



-- Constante de la Turbina de Viento

	REAL A=0.71
	REAL B=230
	REAL C=0.4
	REAL D=20
	REAL E=21
	REAL F=0.00571
						
DECLS

-- Variables entrada
	REAL Teref
	REAL ve
	REAL Betaref

-- Variables de la Turbina

   REAL  Beta						"Angulo de Calaje (C)"
   EXPL REAL  Alp					"Auxiliar Relacion entre la velocidad lineal de las paletas y el viento"
   EXPL REAL  alpha				"Relacion entre la velocidad lineal de las paletas y el viento"
	EXPL REAL  Tmech				"Torque Mecanico (N.m)"	
	EXPL REAL  Pmech				"Potencia mecanica (W)"
	EXPL REAL  alphai				"Normalizado Relacion entre la velocidad lineal de las paletas y el viento"
	REAL Cp							"Coeficiente de Potencia"
	REAL Cpa							"Coeficiente de Potencia"

-- Variables del Generador
	
	REAL wt							"Velocidad angular de la turbina de viento (rad/seg)" 
	REAL id							"Corriente del estator del generador en el eje d (Amps)"
	REAL iq							"Corriente del estator del generador en el eje q (Amps)"
	REAL vd							"Voltaje del estator en el eje d- directo (Volts)"
	REAL vq							"Voltaje del estator en el eje de cuadratura - q (Volts)"
	REAL xa							"Auxiliar del controlador de corriente eje D"
	REAL xb							"Auxiliar del controlador de corriente eje Q"	
	EXPL REAL iqref				"Corriente de referencia en el eje q"
	 		
INIT

	Beta=3
	wt=9.28	
	id=0
	xa=0
	iq=151.97
	xb=0.5922

      
CONTINUOUS

-- ************  Definicion de las variables de entrada  ******************

	ve=WindVeSourceb.Ve
	Teref=WTCPuertosb.Teref
   Betaref=WTCPuertosb.Betaref
	
-- ************  Definicion del Actuador Angulo de Pitch *******************	

	Tservo*Beta'=Betaref-Beta


-- ******************  Definicion de Alpha   *******************************			
			
	Alp= ZONE (ve==0) 0
	  	  OTHERS R*(wt/ve)
	  		 
	alpha= ZONE (Alp<=0) 0
	  	    OTHERS Alp	
	
-- ******************  Definicion de Cpa   *********************************
	
	alphai= ZONE (alpha==0) 0
	  	     OTHERS 1/((1/(alpha+(0.08*Beta)))-(0.035/((Beta**3)+1)))
	
	Cpa=ZONE (alpha==0) 0
	  	  OTHERS (A*((B/alphai)-(C*Beta)-D)*exp(-E/alphai))+(F*alpha)
					
	Cp=  ZONE (Cpa<0) 0       
	  	  OTHERS Cpa
	
	Tmech= ZONE (alpha==0) 0       
	  	    OTHERS 0.5*denso*PI*(R**3)*Cp*(ve**2)/alpha
	  	    
	Pmech= ZONE (alpha==0) 0       
	  	    OTHERS 0.5*denso*PI*(R**2)*Cp*(ve**3)*(1/3) 	    
	  	   
-- *************************  Drive Train   *********************************	
			       	
	Jt*wt'= Tmech-((1.5*np*phi)*iq)-(Fr*wt)  
	  	    

-- ********** Controladores de Corriente del Generador **********************	

	xa'=idref-id
		
	vd=kp*(idref-id)+(ki*xa)-(Ls*np*wt*iq)  
	
	iqref=(2/(3*np*phi))*Teref
	
	xb'=iqref-iq
	
	vq=kp*(iqref-iq)+(ki*xb)+(Ls*np*wt*id)-(np*phi*wt)
	
   
-- **************************** Generator   *********************************	   				
			
	Ls*id'=vd+(Ls*np*wt*iq)-(Rs*id) 		
			
	Ls*iq'=vq-(Rs*iq)-(Ls*np*wt*id)+(np*phi*wt)		
	
	WTPuertosb.wt=wt
	PotPuertosb.Pmech=Pmech
	
	
END COMPONENT

--******************************************************************************
--                        CONTROLADOR DE LA TURBINA
--******************************************************************************

COMPONENT PITurbina
	"Controlador PI de una turbina elica"

PORTS

---------------------------------------------------------------------------- 	
-- Entradas: Ve, wt
----------------------------------------------------------------------------
	
		IN  WindVeSource  			WindVeSourcea 		
		IN  WTPuertos					WTPuertosa 
	
---------------------------------------------------------------------------
--Salida: Teref , Betaref
----------------------------------------------------------------------------
		
		OUT WTCPuertos  			   WTCPuertosa
           	
DATA
	
	REAL alphaop=6.96					 "Relacion optima entre la velocidad lineal de las paletas y el viento"
   REAL Terefop=410.4531          "Operate point for torque"
   REAL kp=6.629  					 "Constante del controlador de corriente PI"
	REAL ki=7.627						 "Constante del controlador de corriente PI"
	REAL R=4.5							"Radio de la palas de la turbina (m)" 
						
DECLS

	REAL ve								 "Velocidad del viento (m/s)"
	REAL wt								 "Velocidad angular de la turbina de viento (rad/seg)" 
	REAL xa                        "Auxiliar del controlador"
	REAL Teref                     "Torque de referencia (Nw.m)"
	REAL wtref							 "Velocidad angular de referencia de la turbina de viento (rad/seg)"
	REAL wtrefa							 "Variable auxiliar"
	REAL Betaref						 "Angulo de Calaje de referencia (C)"


INIT

      
CONTINUOUS

	ve=WindVeSourcea.Ve
	wt=WTPuertosa.wt
	
	wtrefa=(alphaop/R)*ve	
		
	wtref = ZONE (wtrefa>14.65) 14.65  --14.65
	        ZONE (wtrefa<0) 0
	  	     OTHERS wtrefa 
	  	  
	xa'=wt-wtref
		
	Teref=kp*(wt-wtref)+(ki*xa)+Terefop
		
	Betaref=3

	WTCPuertosa.Teref=Teref
   WTCPuertosa.Betaref=Betaref

END COMPONENT

--******************************************************************************
--                        DataViento
--******************************************************************************

COMPONENT DataViento
	"Datos de viento aprovechable"

PORTS

---------------------------------------------------------------------------
--Salida: Ve
----------------------------------------------------------------------------
		
		OUT WindVeSource  			WindVeSourcec
           	
DATA
		TABLE_1D tabve= {{0.,600,1200,1800,2400,3000,3600,4200,4800,5400,6000,6600,7200,7800}, {6,7,8.6,9,10,11,10,9,8.6,7,6.2,5,4,3}}  "Datos de velocidad de viento"
   							
						
DECLS

   
	REAL va							"Velocidad del viento (m/seg)"

      
CONTINUOUS

   va=timeTableInterp(TIME,tabve) 
   

	WindVeSourcec.Ve=va

END COMPONENT
