USE MATH

-- Fecha de Actualizacion: 22/04/2012
/*
COMPONENT ArregloSolar
	"Grficas de descripcin del mdulo solar. Resultados no incluidos en la simulacin."
-- El objetivo del presente modulo son grficas de descripcin
-- para el modulo Solar que se esta utilizando
-- son de simple consulta para el programador
-- y sus resultados no sern incluidos en el resto de la simulacion
-- Module Used: Wuxi Green Energy Source - 185Wp

DATA

	
-- Module Used: Wuxi Green Energy Source - 185Wp
	
	REAL Vocmstc=44.8 		" Voltaje a Circuito Abierto - Modulo (Volts)"
	REAL Iscmstc=5.51			" Corriente a corto circuito - Modulo (Amps)"
	REAL NOCT=46				" Temperatura de celda de operacin normal (C)"
	REAL Vmpmstc=36.2			" Voltaje a la mxima potencia - Modulo (Volts)"
	REAL Impmstc=5.11			" Corriente a la mxima potencia - Modulo (Amps)"
	REAL Pmaxmstc=185 		" Potencia a la mxima potencia - Modulo (Wp)"
	REAL Tref=25				" Temperatura de Referencia (C)"
	REAL Gstc=1000				" Radiacin Solar en condiciones estandar(w/m2)"
	REAL Efficiency=14.6		" Eficiencia del modulo (%)"
	REAL Beta=-0.38			" Sensibilidad del voltaje de circuito abierto a la temperatura (%/C)"
	REAL Alfa=0.10				" Sensibilidad de la corriente de corto circuitoa la temperatura (%/C)"
	REAL Gamma=-0.47			" Sensibilidad de la mxima potencia a la temperatura (%/C)"
	REAL Surface = 1.277 	" Superficie del modulo (m2)"
	REAL Nsc=12					" Nmero de celdas en serie dentro de un modulo"
	REAL Npc=6 					" Nmero de celdas en paralelo de un modulo"
	REAL Npm=3					" Nmero de modulos en paralelo dentro de un arreglo solar"
	REAL Nsm=9					" Nmero de modulos en serie dentro de un arreglo solar"

					
-- Constantes

	REAL vt=0.0248				" Voltaje Trmico (Volts)" 
	
-- Valores Geogrficos

-- Periodo: Tunis weather data from 2007/12/12 to 2008/12/18
-- Radiacion Solar -> MIN: 0  -> MAX=1009
-- Temperatura -> MIN=2.133   -> MAX=40.383

-- a) Analisis de la Temperatura
	
	REAL G[7]={1000,1000,1000,1000,1000,1000,1000}			      " Radiacin Solar (w/m2)"
	REAL Tenv[7]={0,5,10,15,20,25,30} 				 		" Temperatura ambiente (C)"
   
DECLS
 		
	EXPL REAL Tcell[7]			" Temperatura de celda (C)"
	EXPL REAL Vocg[7]				" Voltaje a circuito abierto - Arreglo (Volts)"
	EXPL REAL Iscg[7]				" Corriente a corto circuito - Arreglo (Amps)"
	EXPL REAL Voc					" Voltaje a circuito abierto de una celda (Volts)"	
	EXPL REAL Vocn				   " Voltaje normalizado a circuito abierto de una celda"	
	EXPL REAL Isc					" Corriente a corto circuito de una celda (Amps)"	
	EXPL REAL Pmax				   " Potencia mxima de una celda (Wp)"	
	EXPL REAL FF					" Factor de Forma STC para una celda solar"	
	EXPL REAL FFo					" Factor de Forma STC para una celda ideal"	
	EXPL REAL rs					" Resistencia normalizada en serie de una celda"	
	EXPL REAL Rsm					" Resistencia en serie de un modulo(Ohms)"	
	EXPL REAL Rsg					" Resistencia en serie - arreglo (Ohms)"
	REAL Vpvg						" Voltaje de salida (Volts)"
	REAL Ipvg[7]					" Auxiliar corriente de salida (Amps)"
	REAL Ppv[7]						" Potencia de salida (W)"
	REAL Imax[7]					" Corriente en el punto de mxima potencia (Amps)"
	REAL Vmax[7]					" Voltaje en el punto de mxima potencia (Volts)"
	REAL Pmpp[7]					" Punto de mxima potencia (W)"
	REAL dIdV[7]					" Derivada de la corriente con respecto al voltaje"
	REAL Ipvga[7]					" Corriente de salida (Amps)"

INIT
    	     
CONTINUOUS

-------------------- Calcular Resistencia en serie de un arreglo solar-------------------------
 
-- a) Caractersticas de una celda solar:
		Voc=Vocmstc/Nsc
		Vocn=Voc/vt
		Isc=Iscmstc/Npc
		Pmax=Pmaxmstc/(Npc*Nsc)
		
-- b) Factor de Forma STC para una celda solar:
		FF=Pmax/(Isc*Voc)					
		
-- c) Factor de forma para una celda ideal sin considerar la resistencia serie:
		FFo=(Vocn-log(Vocn+0.72))/(Vocn+1)
		
-- d) Resistencia en serie de una celda solar normalizada:
		rs =1-(FF/FFo)					

-- e) Resistencia en serie de un modulo solar:
		Rsm=rs*Vocmstc/Iscmstc    	

-- f) Resistencia en serie de un arreglo solar:		
		Rsg=Rsm*Nsm/Npm 

	 EXPAND_BLOCK   (i IN 1, 7)
	 
	-- Temperatura de Trabajo
	 
	Tcell[i]=Tenv[i]+(G[i]*(NOCT-20)/800)
   
   -- Voltaje a circuito abierto 	
			
	Vocg[i]=Nsm*Vocmstc*(1+ (Beta*(Tcell[i]-Tref)/100))
	
	-- Corriente a Corto Circuito 
	
	Iscg[i]= Npm*Iscmstc * G[i] * (1 + (Alfa*(Tcell[i] - Tref)/100))/ Gstc 
	
	-- Corriente del Panel Solar
	
	Ipvg[i]=Iscg[i]*(1-exp((Vpvg+Rsg*Ipvg[i]-Vocg[i])/(vt*Nsm*Nsc)))
	
	Ipvga[i]= ZONE (Ipvg[i]<=0) 0
				OTHERS Ipvg[i]
	
	-- Potencia del Panel Solar
	
	Ppv[i]=Ipvga[i]*Vpvg
	
	--Calcula de la mxima potencia

	--Imax + Vmax*dIdV = 0	-- dP/dV = 0
   Imax[i] = - Vmax[i]*dIdV[i] 				-- dP/dV = 0
 		 					 
	--(1 + dIdV*Rsg)*(Isc - Imax) = - Kv*dIdV		
	dIdV[i] = (-Iscg[i]*exp((Vmax[i]+Rsg*Imax[i]-Vocg[i])/(vt*Nsm*Nsc))/(vt*Nsm*Nsc))/(1-(-Iscg[i]*Rsg*exp((Vmax[i]+Rsg*Imax[i]-Vocg[i])/(vt*Nsm*Nsc))/(vt*Nsm*Nsc)))
								
	--Vmax + Imax*Rsg = Kv*log(1- Imax/Isc) + Voc
	Vmax[i] = ((vt*Nsm*Nsc)*log10(1- Imax[i]/Iscg[i])) + Vocg[i] - Imax[i]*Rsg
	
	Pmpp[i]=Imax[i]*Vmax[i]
  
    END EXPAND_BLOCK
	
END COMPONENT


/*COMPONENT MPPtranckingnew
	"Mdulo para optimizar el punto de mxima potencia fotovoltaica"

-- El objetivo del presente modulo es calcular el voltaje
-- en el punto de mxima potencia, ser enviado al inversor

PORTS

-- Entradas: G, Tenv

	IN SolarSource  	  	SolarSourceb	
	
-- Salidas: Vop

	OUT MPPTOpt				MPPTOpta


DATA

	
-- Module Used: Wuxi Green Energy Source - 185Wp
	
	REAL Vocmstc=44.8 		" Voltaje a Circuito Abierto - Modulo (Volts)"
	REAL Iscmstc=5.51			" Corriente a corto circuito - Modulo (Amps)"
	REAL NOCT=46				" Temperatura de celda de operacin normal (C)"
	REAL Vmpmstc=36.2			" Voltaje a la mxima potencia - Modulo (Volts)"
	REAL Impmstc=5.11			" Corriente a la mxima potencia - Modulo (Amps)"
	REAL Pmaxmstc=185 		" Potencia a la mxima potencia - Modulo (Wp)"
	REAL Tref=25				" Temperatura de Referencia (C)"
	REAL Gstc=1000				" Radiacin Solar en condiciones estandar(w/m2)"
	REAL Efficiency=14.6		" Eficiencia del modulo (%)"
	REAL Beta=-0.38			" Sensibilidad del voltaje de circuito abierto a la temperatura (%/C)"
	REAL Alfa=0.10				" Sensibilidad de la corriente de corto circuitoa la temperatura (%/C)"
	REAL Gamma=-0.47			" Sensibilidad de la mxima potencia a la temperatura (%/C)"
	REAL Surface = 1.277 	" Superficie del modulo (m2)"
	REAL Nsc=12					" Nmero de celdas en serie dentro de un modulo"
	REAL Npc=6 					" Nmero de celdas en paralelo de un modulo"
	REAL Npm=3					" Nmero de modulos en paralelo dentro de un arreglo solar"
	REAL Nsm=9					" Nmero de modulos en serie dentro de un arreglo solar"

					
-- Constantes

	REAL vt=0.0248				" Voltaje Trmico (Volts)" 
	

DECLS
 		
 	REAL G						   " Radiacin Solar (w/m2)"
	REAL Tenv   			 		" Temperatura ambiente (C)"
	EXPL REAL Tcell				" Temperatura de celda (C)"
	EXPL REAL Vocg					" Voltaje a circuito abierto - Arreglo (Volts)"
	EXPL REAL Iscg					" Corriente a corto circuito - Arreglo (Amps)"
	EXPL REAL Voc					" Voltaje a circuito abierto de una celda (Volts)"	
	EXPL REAL Vocn				   " Voltaje normalizado a circuito abierto de una celda"	
	EXPL REAL Isc					" Corriente a corto circuito de una celda (Amps)"	
	EXPL REAL Pmax				   " Potencia mxima de una celda (Wp)"	
	EXPL REAL FF					" Factor de Forma STC para una celda solar"	
	EXPL REAL FFo					" Factor de Forma STC para una celda ideal"	
	EXPL REAL rs					" Resistencia normalizada en serie de una celda"	
	EXPL REAL Rsm					" Resistencia en serie de un modulo(Ohms)"	
	EXPL REAL Rsg					" Resistencia en serie - arreglo (Ohms)"
	REAL Imax						" Corriente en el punto de mxima potencia (Amps)"
	REAL Vmax						" Voltaje en el punto de mxima potencia (Volts)"
	REAL dIdV						" Derivada de la corriente con respecto al voltaje"
	REAL Pmaxout					" Potencia mxima de salida del arreglo solar (W)"

INIT
    	     
CONTINUOUS

	Tenv=SolarSourceb.Tenv
	G=SolarSourceb.G  

-------------------- Calcular Resistencia en serie de un arreglo solar-------------------------
 
-- a) Caractersticas de una celda solar:
		Voc=Vocmstc/Nsc
		Vocn=Voc/vt
		Isc=Iscmstc/Npc
		Pmax=Pmaxmstc/(Npc*Nsc)
		
-- b) Factor de Forma STC para una celda solar:
		FF=Pmax/(Isc*Voc)					
		
-- c) Factor de forma para una celda ideal sin considerar la resistencia serie:
		FFo=(Vocn-log(Vocn+0.72))/(Vocn+1)
		
-- d) Resistencia en serie de una celda solar normalizada:
		rs =1-(FF/FFo)					

-- e) Resistencia en serie de un modulo solar:
		Rsm=rs*Vocmstc/Iscmstc    	

-- f) Resistencia en serie de un arreglo solar:		
		Rsg=Rsm*Nsm/Npm 
 
	-- Temperatura de Trabajo
	 
	Tcell=Tenv+(G*(NOCT-20)/800)
   
   -- Voltaje a circuito abierto 	
			
	Vocg=Nsm*Vocmstc*(1+ (Beta*(Tcell-Tref)/100))

	-- Corriente a Corto Circuito 
	
	Iscg=Npm*Iscmstc*G*(1+(Alfa*(Tcell-Tref)/100))/Gstc 

	--Calcula de la mxima potencia

	--Imax + Vmax*dIdV = 0	-- dP/dV = 0
   Imax= ZONE (G<=10)0
   		OTHERS -Vmax*dIdV 				
 		 					 
	--(1 + dIdV*Rsg)*(Isc - Imax) = - Kv*dIdV		
	dIdV=(-Iscg*exp((Vmax+Rsg*Imax-Vocg)/(vt*Nsm*Nsc))/(vt*Nsm*Nsc))/(1-(-Iscg*Rsg*exp((Vmax+(Rsg*Imax)-Vocg)/(vt*Nsm*Nsc))/(vt*Nsm*Nsc)))
								
	--Vmax + Imax*Rsg = Kv*log(1- Imax/Isc) + Voc
	Vmax=ZONE (G<=10) Vocg
	     OTHERS ((vt*Nsm*Nsc)*log10(1-(Imax/Iscg)))+Vocg-Imax*Rsg
	
	Pmaxout=Vmax*Imax
	
	
	MPPTOpta.Vmax=Vmax
	MPPTOpta.Iscg=Iscg
	MPPTOpta.Pmax=Pmaxout
  
END COMPONENT
*/

/*COMPONENT BoostConverterNew
	"Convertidor Boost CC/CC"

-- El objetivo del presente modulo es la modulacion del cirtuito Boost
-- sus resultados estarn incluidos en el resto de la simulacion


PORTS

--Entrada: Vop proveniente del optimizador 

		IN MPPTOpt				MPPTOptb
		
--Salida: Vop dirigido a los paneles solares

	  OUT BoostPSolar			BoostPSolara

			
DATA

		REAL Ti=0.1				  						"Constante de tiempo del Boost Converter"
		   
DECLS

	   REAL Volte										"Punto de trabajo del arreglo solar (Volt)"
	   REAL Volta										"Punto de referencia del arreglo solar (Volt)"

		
INIT

     Volte=387
    	     
CONTINUOUS

	Volta=MPPTOptb.Vmax
	
	Ti*Volte'=Volta-Volte
	
	BoostPSolara.Vop=Volte
 
END COMPONENT
*/

COMPONENT SolarNew
	"Modelo de colector fotovoltaico"

PORTS

---------------------------------------------------------------------------
--Entradas: G, Tenv,Vop
----------------------------------------------------------------------------
		
		IN SolarSource  			SolarSourceb
//		IN BoostPSolar				BoostPSolarb
		
---------------------------------------------------------------------------
--Salidas: Potencia de salida
----------------------------------------------------------------------------		
				
//		OUT PgridFuente			PgridFuentea	
		OUT SolInv					SolInva
    	
DATA


-- Module Used: Wuxi Green Energy Source - 185Wp
	
	REAL Vocmstc=44.8 		" Voltaje a Circuito Abierto - Modulo (Volts)"
	REAL Iscmstc=5.51			" Corriente a corto circuito - Modulo (Amps)"
	REAL NOCT=46				" Temperatura de celda de operacin normal (C)"
	REAL Vmpmstc=36.2			" Voltaje a la mxima potencia - Modulo (Volts)"
	REAL Impmstc=5.11			" Corriente a la mxima potencia - Modulo (Amps)"
	REAL Pmaxmstc=185 		" Potencia a la mxima potencia - Modulo (Wp)"
	REAL Tref=25				" Temperatura de Referencia (C)"
	REAL Gstc=1000				" Radiacin Solar en condiciones estandar(w/m2)"
	REAL Efficiency=14.6		" Eficiencia del modulo (%)"
	REAL Beta=-0.38			" Sensibilidad del voltaje de circuito abierto a la temperatura (%/C)"
	REAL Alfa=0.10				" Sensibilidad de la corriente de corto circuitoa la temperatura (%/C)"
	REAL Gamma=-0.47			" Sensibilidad de la mxima potencia a la temperatura (%/C)"
	REAL Surface = 1.277 	" Superficie del modulo (m2)"
	REAL Nsc=12					" Nmero de celdas en serie dentro de un modulo"
	REAL Npc=6 					" Nmero de celdas en paralelo de un modulo"
	REAL Npm=3					" Nmero de modulos en paralelo dentro de un arreglo solar"
	REAL Nsm=9					" Nmero de modulos en serie dentro de un arreglo solar"

					
-- Constantes

	REAL vt=0.0248				" Voltaje Trmico (Volts)" 
   REAL Ti=0.1				  	"Constante de tiempo del Boost Converter"
	
DECLS
   		
/*	EXPL REAL Tcell				" Temperatura de celda (C)"
	EXPL REAL Vocg 				" Voltaje a circuito abierto - Arreglo (Volts)"
	EXPL REAL Iscg 				" Corriente de corto cicuito - Arreglo (Amps)"
	EXPL REAL Voc					" Voltaje a circuito abierto de la celda (Volts)"	
	EXPL REAL Vocn				   " Voltaje a circuito abierto de la celda normalizado"	
	EXPL REAL Isc					" Corriente de corto circuito de una celda (Amps)"	
	EXPL REAL Pmax				   " Potencia mxima de una celda (Wp)"	
	EXPL REAL FF					" Factor de Forma STC para una celda solar"	
	EXPL REAL FFo					" Factor de Forma STC para una celda ideal"	
	EXPL REAL rs					" Resistencia en serie de una celda normalizada "	
	EXPL REAL Rsm					" Resistencia en serie de un modulo (Ohms)"	
	EXPL REAL Rsg					" Resistencia en serie - arreglo (Ohms)"
	EXPL REAL Vpvg					" Voltaje del arreglo solar (Volts)"
	REAL Ipvg						" Corriente del arreglo solar (Amps)"
	REAL G							"Radacin Solar (w/m2)"
	REAL Tenv						"Temperatura Ambiente (C)"	
	EXPL REAL Pout					"Potencia de salida (W)"
*/
	REAL G						   " Radiacin Solar (w/m2)"
	REAL Tenv   			 		" Temperatura ambiente (C)"
	EXPL REAL Tcell				" Temperatura de celda (C)"
	EXPL REAL Vocg					" Voltaje a circuito abierto - Arreglo (Volts)"
	EXPL REAL Iscg					" Corriente a corto circuito - Arreglo (Amps)"
	EXPL REAL Voc					" Voltaje a circuito abierto de una celda (Volts)"	
	EXPL REAL Vocn				   " Voltaje normalizado a circuito abierto de una celda"	
	EXPL REAL Isc					" Corriente a corto circuito de una celda (Amps)"	
	EXPL REAL Pmax				   " Potencia mxima de una celda (Wp)"	
	EXPL REAL FF					" Factor de Forma STC para una celda solar"	
	EXPL REAL FFo					" Factor de Forma STC para una celda ideal"	
	EXPL REAL rs					" Resistencia normalizada en serie de una celda"	
	EXPL REAL Rsm					" Resistencia en serie de un modulo(Ohms)"	
	EXPL REAL Rsg					" Resistencia en serie - arreglo (Ohms)"
	REAL Imax						" Corriente en el punto de mxima potencia (Amps)"
	REAL Vmax						" Voltaje en el punto de mxima potencia (Volts)"
	REAL dIdV						" Derivada de la corriente con respecto al voltaje"
	EXPL REAL Pmaxout				" Potencia mxima de salida del arreglo solar (W)"
	
	REAL Volte										"Punto de trabajo del arreglo solar (Volt)"


INIT

   Volte=387
    	     
CONTINUOUS

	Tenv=SolarSourceb.Tenv
	G=SolarSourceb.G  
//	Vpvg=BoostPSolarb.Vop   
 
	-------------------- Calcular Resistencia en serie de un arreglo solar-------------------------

-- a) Caractersticas de una celda solar:
		Voc=Vocmstc/Nsc
		Vocn=Voc/vt
		Isc=Iscmstc/Npc
		Pmax=Pmaxmstc/(Npc*Nsc)
		
-- b) Factor de Forma STC para una celda solar:
		FF=Pmax/(Isc*Voc)					
			
-- c) Factor de forma para una celda ideal sin considerar la resistencia serie:
		FFo=(Vocn-log(Vocn+0.72))/(Vocn+1)
				
-- d) Resistencia en serie de una celda solar normalizada:
		rs =1-(FF/FFo)					
		
-- e) Resistencia en serie de un modulo solar:
		Rsm=rs*Vocmstc/Iscmstc    	
		
-- f) Resistencia en serie de un arreglo solar:		
		Rsg=Rsm*Nsm/Npm 
		
	-- Temperatura de Trabajo
	
	Tcell=Tenv+(G*(NOCT-20)/800)
	
	-- Voltaje a circuito abierto 	
			
	Vocg=Nsm*Vocmstc*(1+ (Beta*(Tcell-Tref)/100))
	
	-- Corriente a Corto Circuito 
	
	Iscg= Npm*Iscmstc*G*(1+(Alfa*(Tcell-Tref)/100))/ Gstc 
	
	
	
	--Calcula de la mxima potencia (optimizador)

	--Imax + Vmax*dIdV = 0	-- dP/dV = 0
   Imax= ZONE (G<=10)0
   		OTHERS -Vmax*dIdV 				
 		 					 
	--(1 + dIdV*Rsg)*(Isc - Imax) = - Kv*dIdV		
	dIdV=(-Iscg*exp((Vmax+Rsg*Imax-Vocg)/(vt*Nsm*Nsc))/(vt*Nsm*Nsc))/(1-(-Iscg*Rsg*exp((Vmax+(Rsg*Imax)-Vocg)/(vt*Nsm*Nsc))/(vt*Nsm*Nsc)))
								
	--Vmax + Imax*Rsg = Kv*log(1- Imax/Isc) + Voc
	Vmax=ZONE (G<=10) Vocg
	     OTHERS ((vt*Nsm*Nsc)*log10(1-(Imax/Iscg)))+Vocg-Imax*Rsg
	
	
	--Suaviza la tensin mxima del optimizador
	
	Ti*Volte'=Vmax-Volte
	
	Pmaxout=Volte*Imax
	
	SolInva.Vmax=Vmax
	SolInva.Imax=Imax
	SolInva.Pact=Pmaxout
	SolInva.Iscg=Iscg

//	PgridFuentea.Pact=Pmaxout
	
	
/*	
	-- Corriente del arreglo solar
		   
   Ipvg=Iscg*(1-exp((Vpvg+Rsg*Ipvg-Vocg)/(vt*Nsm*Nsc)))
   
   -- Potencia de Salida
   
   Pout=Ipvg*Vpvg
   
   PgridFuentea.Pact=Pout
*/	
END COMPONENT


--******************************************************************************
--                        DataSolar
--******************************************************************************

COMPONENT DataSolarA
	"Datos de radiacin solar aprovechable"

PORTS

---------------------------------------------------------------------------
--Salida: G, Tenv
----------------------------------------------------------------------------
		
		OUT SolarSource  			SolarSourcea
           	
DATA
		TABLE_1D tabG= {{0.,100,200,300,400,500}, {17,117,517,217,17,0}} "Datos radiacin solar"
		REAL Tenv=25							"Temperatura ambiente (C)"
		REAL Ti=10							 	"Constante de tiempo del sensor de radiacin solar"
						
DECLS
	 
	 REAL Ge										"Radiacin Solar (w/m2)"
	 REAL Ga										"Radiacin Solar (w/m2)"		
   

INIT

	Ge=17
      
CONTINUOUS

	Ga=timeTableStep(TIME,tabG) 
	
	 -- ************  Definicion del sensor de velocidad *******************	

	Ti*Ge'=Ga-Ge

	SolarSourcea.Tenv=Tenv
	SolarSourcea.G=Ge

END COMPONENT

COMPONENT DataSolarB
	"Datos de radiacin solar aprovechable"

---------------------------------------------------------------------------
-- Se tienen datos reales
----------------------------------------------------------------------------

PORTS

---------------------------------------------------------------------------
--Salida: G, Tenv
----------------------------------------------------------------------------
		
		--OUT SolarMPPT  			SolarMPPTa
		OUT SolarSource  			SolarSourcea
           	
DATA
		

	 TABLE_1D tabG= {{0.,25200,25800,26400,27000,27600,28200,28800,29400,30000,30600,31200,31800,32400,33000,33600,
	34200,34800,35400,36000,36600,37200,37800,38400,39000,39600,40200,40800,41400,42000,42600,43200,
	43800,44400,45000,45600,46200,46800,47400,48000,48600,49200,49800,50400,51000,51600,52200,52800,
	53400,54000,54600,55200,55800,56400,57000,57600,58200,58800,59400,60000,60600,61200,61800,62400,
	63000,63600,64200}, 
	{0.,0.9,4.6,11.7,14.5,18.7,25.5,36.6,74.8,69.9,75.8,95.8,260,291.2,319.2,345.8,377.1,400.8,
	235.6,417.7,350,516.2,554.6,595.5,209.8,216.9,158,55.2,31.2,100.1,165.7,332.9,
	613.5,693,362.3,190.6,
	186.3,340.9,576.1,735.5,288,456.4,444.5,499,551.6,437.3,255.2,327.3,480.2,252.6,239.6,288,292.2,255.2,
	219.7,239.1,215.4,191.4,138.8,54.4,60.4,62.9,40.7,17.4,9,4.8,1.4}}	"Curva de variacin de radiacin solar (W/m2)"
	
	TABLE_1D tabTenv={{0.,3600,7200,10800,14400,18000,21600,25200,28800,32400,36000,39600,43200,
	46800,50400,54000,57600,61200,64800,68400,72000,75600,79200,82800,86400}, 
	{12.6,12.7,12.5,12.4,12.4,12.1,12,12.1,12.6,13.6,14.5,15.1,14.9,
	15.3,15.6,15.5,15.2,14.6,14,13.7,13.5,13,12.8,12.6,12.4}}				"Curva de variacin de temperatura (C)"
						
DECLS

	 REAL Ga										"Radiacin Solar (w/m2)"		
    REAL Tenv									"Temperatura ambiente (C)"

CONTINUOUS

	Ga=timeTableInterp(TIME,tabG) 
	Tenv=timeTableInterp(TIME,tabTenv) 
	
	SolarSourcea.Tenv=Tenv
	SolarSourcea.G=Ga

END COMPONENT


