USE MATH


--------------------------------------------------------------------------------
--                        MODELO DEL GENERADOR DIESEL 
--------------------------------------------------------------------------------

COMPONENT DieselEngine
	"Modelo de generador diesel"

PORTS

--------------------------------------------------------------------------------
--    Entradas: torque del generador
--------------------------------------------------------------------------------
			
	IN DieEngGen				DieEngGena
     
           	
DATA

	
	REAL Ka=1.15        				" Engine Torque Constant (pu)"
	REAL Kb=1           				" Actuator torque (pu)"
	REAL Kc=1           				" Current Driver Torque (pu)"
	REAL tau2=0.125     				" Actuator Time constant (s)"
	REAL H=1.666        				" Inertia constant (s)"
	REAL Kd=0.1         				" Damping Factor (pu)"
	REAL tau1=0.5       				" Engine dead time (s)"
	REAL Wo=1							" Velocidad Angular inicial (pu)"
	REAL Wr=1							" Velocidad Angular de referencia (pu)"
	REAL kp=2							" Constante proporcional PI (--)"
	REAL ki=0.5							" Constante proporcional PI (--)"
	REAL Wbase=314.1593				" Velocidad angular del sistema (rad/s)"
	
				
DECLS

	EXPL REAL Wreal					" Velocidad angular del sistema (rad/s)"
	REAL u								" Seal de control"
	REAL i								" Driving Current"
	REAL phi								" Amount of fuel"
	REAL Tmech							" Par mecanico (pu)"
	REAL We								" Velocidad Angular (pu)"
	REAL W								" Velocidad Angular (pu)"
	REAL Tsg								" Par del generador (pu)"
	REAL xa								" Variable interna del sistema (pu)"
	 		
INIT


		      
CONTINUOUS

	Tsg=DieEngGena.Tsg
	
	-- Current Driver Model
	i=Kc*u		
	
	-- Actuator Model	
	tau2*phi'=(i*Kb)-phi	
	
	-- Engine Model	
	Tmech=Ka*delay(phi,tau1)
	
	-- Flywheel Model	
	2*H*We'=Tmech-Tsg-(Kd*We)
	
	W=We+Wo
	
	xa'=Wr-W
		
	u=kp*(Wr-W)+(ki*xa)
	
	Wreal=Wbase*W

			
END COMPONENT


COMPONENT GeneradorSincrono
	"Modelo de generador sncrono"

PORTS

--------------------------------------------------------------------------------
--    Entrada: Voltaje de excitacion
--------------------------------------------------------------------------------

	IN ExciGen					ExciGena

--------------------------------------------------------------------------------
--    Salidas: torque del generador
--------------------------------------------------------------------------------
			
	OUT DieEngGen				DieEngGenb
	OUT GenExc					GenExcb

     
           	
DATA
	
	REAL Vdred=0.2					" Voltaje de red en el eje d (pu)"			
	REAL Vqred=0.7					" Voltaje de red en el eje q (pu)"	
	REAL Re=0.01					" Resistencia de la lnea de transmision (pu)"
	REAL Le=0.2						" Inductancia de la lnea de transmision (pu)"	
	REAL Wr=1						" Referencia en la velocidad angular (pu)"
	REAL Rs=0.0451					" Resistencia de armadura (pu)"
	REAL Tado=0.4					" Transitorio en el eje d - constante de tiempo (s)"
	REAL Tbqo=0.014912			" Subtransitorio en el eje q - constante de tiempo (s)"
	REAL Tbdo=0.0064				" Subtransitorio en el eje d - constante de tiempo (s)"
	REAL Lq=1.35					" Inductancia en el eje q (pu)"
	REAL Ld=1.57					" Inductancia en el eje d (pu)"
	REAL Lad=0.21					" Transitorio inductancia en el eje d (pu)"
	REAL Lbq=0.15					" Subtransitorio inductancia en el eje q (pu)"
	REAL Lbd=0.076					" Subtransitorio inductancia en el eje d (pu)"
				
DECLS

	EXPL REAL Vt					" Voltaje del estator (pu)"
	EXPL REAL Tsg					" Par del generador (pu)"
	REAL id							" Corriente de armadura en el eje d (pu)"
	REAL iq							" Corriente de armadura en el eje q (pu)"
	REAL Ebd							" Voltaje subtransitorio en el eje d (pu)"
	REAL Ebq							" Voltaje subtransitorio en el eje q (pu)"
	REAL Eaq							" Voltaje transitorio en el eje q (pu)"
	REAL Efd							" Voltaje de campo en el eje d (pu)"
	REAL Vtd							" Voltaje del estator en el eje d (pu)"
	REAL Vtq							" Voltaje del estator en el eje q (pu)"


	 		
INIT

	
CONTINUOUS

	Efd=ExciGena.Efd

	-- Ecuaciones de red

	id=(((Rs+Re)*(Ebd-Vdred))+(((Wr*Le)+(Wr*Lbq))*(Ebq-Vqred)))/(((Re+Rs)*(Re+Rs))+(((Wr*Le)+(Wr*Lbq))*((Wr*Le)+(Wr*Lbd))))

	iq=(((Rs+Re)*(Ebq-Vqred))-(((Wr*Le)+(Wr*Lbd))*(Ebd-Vdred)))/(((Re+Rs)*(Re+Rs))+(((Wr*Le)+(Wr*Lbd))*((Wr*Le)+(Wr*Lbq))))

	-- Generador Sincrono

	Tbdo*Ebq'=Eaq-(id*((Wr*Lad)-(Wr*Lbd)))-Ebq
	
	Tbqo*Ebd'=(((Wr*Lq)-(Wr*Lbq))*iq)-Ebd
	
	Tado*Eaq'=Efd+(((Ld-Lad)/(Lad-Lbd))*Ebq)-(((Ld-Lbd)/(Lad-Lbd))*Eaq)
	
	-- Tension en los terminales del estator
	
	Vtd=Vdred+(Re*id)-(Wr*Le*iq)
	
	Vtq=Vqred+(Re*iq)+(Wr*Le*id)
	
	Vt=((Vtd**2)+(Vtq**2))**0.5	
	
	-- Par del generador		
	
	Tsg=(Ebd*id)+(Ebq*iq)-(((Lbd*Wr)-(Lbq*Wr))*id*iq)	
	
	DieEngGenb.Tsg=Tsg
	GenExcb.Vt=Vt

			
END COMPONENT



COMPONENT Exciter
	"Sistema de excitacin del generador diesel. Proporciona y ajusta la corriente del generador sncrono"

PORTS

--------------------------------------------------------------------------------
--    Entrada: Voltaje Terminal
--------------------------------------------------------------------------------	
	IN GenExc					GenExcb

--------------------------------------------------------------------------------
--    Salida: Voltaje de excitacion
--------------------------------------------------------------------------------
	OUT ExciGen					ExciGenb
	

           	
DATA

		REAL Kf=0.058					" Ganancia"
		REAL Tfa=0.62					" Constante de tiempo"
		REAL KA=187						" Ganancia"
		REAL TA=0.89					" Constante de tiempo"
		REAL Vtref=1					" Voltaje de referencia del estator (pu)"
		REAL kp=5.0203					" Constante proporcional del controlador PI"
		REAL ki=3.7838e+003			" Constante integral del controlador PI"
	
				
DECLS

		REAL Vt							" Voltaje del estator (pu)"
		REAL xa							" Variable interna"	
		REAL Vs							" Voltaje del transformador de estabilizacion"		
		REAL Efd							" Voltaje de campo en el eje d (pu)"
		REAL u							" Seal de control"
	 		
INIT

	
		      
CONTINUOUS

	Vt=GenExcb.Vt
	
	Tfa*Vs'=(Kf*Efd')-Vs
		
	xa'=Vtref-Vt-Vs
	
	u=kp*(Vtref-Vt-Vs)+(ki*xa)
	
	TA*Efd'=(KA*u)-Efd
	
	ExciGenb.Efd=Efd

END COMPONENT

----------------------------------------------------------------------------------------
--              PRINCIPALES ESPECIFICACIONES
----------------------------------------------------------------------------------------

-- Radio: 0,9
-- Circuit Breaker: 32
-- Battery Charger current: 55A
-- Frecuencia: 50Hz
-- Voltaje: 400V
-- Fase: 3 fases
-- Localizacin del tanque de combustible: Interno
-- Capacidad del Tanque de combustible: 51 litros
-- Tiempo de ejecucin al 100% PRP: 9.97 horas
-- Tiempo de ejecucin al 75% PRP: 13 horas


----------------------------------------------------------------------------------------
--              ESPECIFICACIONES DEL MOTOR DIESEL
----------------------------------------------------------------------------------------

-- Fabricante: Perkins
-- Modelo 404C-22G
-- Tiempos: 4
-- Cantidad de cilindros: 4, inline
-- Velocidad nominal de operacin: 1500rpm
-- Frecuencia: 50Hz
-- Voltaje: 231/400 V

-- Salida Tipica del generador

-- Prime Power:     -- 20.3 KVA
						  -- 16.3 kWe

-- Standby (Maximum):   -- 22.7 KVA
								-- 18.2 kWe

-- Tensin del circuito Elctrico: 12VDC
-- Radio de comprension: 23.3:1
-- Displacement: 2216cc
-- Bore and Stroke 84 x 100 mm
-- Consumo de combustible: 100% carga (Prime Power) -> 5.4 litros/hora
								-- 75% carga -> 4 litros/hora	
								-- 50% carga -> 2.9 litros/hora	
								-- 25% carga -> 2.27 litros/hora		
								-- Atandby Rating -> 6.2 litros/hora			

-- Capacidad del aceite de lubricacion (Lubrication oil capacity): 10.6 litros 
-- Coolant capacity with radiator: 6.98 litros


----------------------------------------------------------------------------------------
--              ESPECIFICACIONES DEL GENERADOR ELECTRICO
----------------------------------------------------------------------------------------

-- Fabricante: Linz
-- Modelo: E1S13M/4/19
-- Nmero de Polos: 4
-- velocidad de revolucion: 1500rpm 
-- Voltaje: 400V
-- Frecuencia: 50Hz
-- Potencia nominal continua a 40C = 19 kVA
-- Potencia nominal continua a 27C = 19 kVA
-- Potencia standby a 27C = 20.1 kVA
-- Potencia activa continua a 27C= 15kW
-- Eficiencia al 75% de carga:  86.5%
-- Eficiencia al 100% de carga: 86%
-- Sobrecarga mxima permitida: 10% por una hora cada 12 horas de ejecucin
-- Sistema de regulacin de voltaje: compuesto
-- Grado de porteccin: IP21



