  USE MATH

/*
--------------------------------------------------------------------------------
--                        COMPONENTE DE LA TURBINA 
--------------------------------------------------------------------------------

COMPONENT turbina

PORTS


       -- Conexion Windy Turbine - Rectificador
       OUT WindrectV      turbineav 
    --   OUT WindrectV      turbinebv
    --   OUT WindrectV      turbinecv
       IN WindrectI       turbineai
     --  IN WindrectI       turbinebi
     --  IN WindrectI       turbineci
       
           	
DATA

----------------------------------------------------------------------------------------	
-- MODELO DEL SUBSISTEMA EOLICO
-- Turbina: Alize 10kW
-- Altura de la Turbina: 30m
-- Data de Velocidad del Viento: 19 de Dicembre de 2007
-- Caja Box protection
-- Wndy Boy 6000
----------------------------------------------------------------------------------------


TABLE_1D Tabve = {{0.5,1.5,2.5,3.5,4.5,5.5,6.5,7.5,8.5,9.5,10.5,11.5,12.5,13.5,14.5,15.5,16.5,17.5,18.5,19.5,20.5,21.5,22.5,23.5},

            {6,6.4,7.32,5.45,5.57,4.38,4.62,4.95,5,4.63,4.6,6.067,5.68,5.03,4.95,5.01,5.183,4.7833,4.716,4.4166,5.45,4.7166,4.166,4.6833}}
	
TABLE_1D Tabgrados = {{0.5,1.5,2.5,3.5,4.5,5.5,6.5,7.5,8.5,9.5,10.5,11.5,12.5,13.5,14.5,15.5,16.5,17.5,18.5,19.5,20.5,21.5,22.5,23.5},

            {241.83,249.5,251.833,246.166,250.833,244.66,229.166,230.666,221.333,219,240.33,260.33,268,264.16,266.833,277.5,284.5,264.66,272.5,260.83,258.5,246.5,222.66,221}}
	
-- Entradas
	
	REAL ve=8						"Velocidad del viento (m/seg)"
	REAL grado = 241.83			"Direccin del viento (Grados)"

-- Datos de la Turbina

	REAL r=4.5						"Radio de la turbina (m)"
	REAL Mt=1100					"Masa de toda la turbina, incluyendo el generador (Kg)"
	REAL Cf=15						"Constante del modelo de Cp"
	REAL Ro=240						"Angulo de posicion de la turbina (degrees)"  --REVISAR

-- Datos del Generador

	REAL p=12							"Nmero de par de polos del generador"
	
	-- Falta revisar
	REAL Lqs=0.074					"Inductancia del estator (H)"
	REAL Lds=0.074					"Inductancia del estator (H)"
	REAL Rs=5.2						"Resistencia del estator (ohmios)"
	REAL phi=1.1 			   	"Flujo magnetico"  --Revisar
	REAL Fr=10						"constante de proporcionalidad de la fuerza de Roce"

	
-- Constantes

	REAL denso=1.2256				"Densidad del aire (kg/m3)"	
				
DECLS

-- Variables de Entradas
	   
	--EXPL REAL ve					"Velocidad del viento (m/seg)"
	--EXPL REAL grado				"Direccin del viento (degrees)"
	
-- Variables de la Turbina

	EXPL REAL  Pviento			"Potencia del viento (W)"
	EXPL REAL  Lamda				"Relacion entre la velocidad lineal de las paletas y el viento"
	EXPL REAL  Beta				"Angulo de inclinacion"	
	REAL Cwt
	EXPL REAL  Pturb				"Potencia que se genera en la turbina (W)"
	REAL Cp							"Coeficiente de Potencia"
	REAL Cpx							"Coeficiente de Potencia"

-- Variables del Generador
	
	EXPL REAL  Jt					"Constante de inercia de la turbina"   --Revisar
	REAL wt							"Velocidad angular de la turbina de viento (rad/seg)" 
	EXPL REAL ids					"Corriente del estator del generador en el eje d (Amps)"
	REAL iqs, iqsx					"Corriente del estator del generador en el eje q (Amps)"
	REAL vds							"Voltaje del estator en el eje d- directo (Volts)"
	REAL vqs							"Voltaje del estator en el eje de cuadratura - q (Volts)"
	REAL Pgen						"Potencia del Generador (W)"
	REAL Im							"Corriente pico del generador (Amps)"
	REAL Vm							"Voltaje pico del Generador (Volts)"
	
	 		
INIT
		wt = 10
      iqs = 0
  		vqs=0
      
CONTINUOUS

----------------------------------------------------------------------------
--                  DATOS DE ENTRADA
----------------------------------------------------------------------------

		
-- Definir la direccion y velocidad del viento en funcion del tiempo

		--	ve = timeTableInterp(TIME,Tabve)
			
		--	grado = timeTableInterp(TIME,Tabgrados)
			
----------------------------------------------------------------------------
--                  MODELO DE LA TURBINA
----------------------------------------------------------------------------
 		
	  		Pviento=denso*PI*(r**2)*(ve**3)/2
	  
	 		Beta=abs(Ro-grado)
	  
	  		Lamda=wt*r/ve
	  			  		
	  		
	  		Cp= ZONE (Cpx<0) 0
				 OTHERS Cpx
			
			Cpx= ZONE (Lamda<=1) 0
				  OTHERS (1/2)*((r*Cf/Lamda)-0.322*Beta-2)*exp(-0.255*(r*Cf/Lamda))	  		
			
			  			  		
	  		Pturb=Cp*Pviento



----------------------------------------------------------------------------
--                  MODELO MECANICO ENTRE TURBINA Y GENERADOR
----------------------------------------------------------------------------	  		
	  		 		
	  		-- Suma del momento de inercia de la turbina y del generador 		
			Jt=1--(1/2)*Mt*(r**2)  
						     		
			(Jt)*wt'=(((Cp*Pviento)/wt)+(Cwt*3*p*(phi*iqs)/2)-Fr*wt)
		
		-- Condicion para encender turbina
		
			Cwt= 1--ZONE (wt>=5.23  ) 1 
				-- OTHERS 0
		
		
			/*wtx'= ZONE (wt==wtmin) 0
				   ZONE (wt==wtmax) 0
				   OTHERS (((Cp*Pviento)/wt)-(3*p*((phi*iqs)+(Lds-Lqs)*iqs*ids)/2))/(Jt+Jr)	     				
				     				
		 	wt=wtx*/	
				
				
----------------------------------------------------------------------------
--                 MODELO ELECTRICO DEL GENERADOR
----------------------------------------------------------------------------	  
		  	
			---vds-Rs*ids-(p*wt)*Lqs*iqs=0     -- vds tiene el mismo signo que iqs
			
			
			--(3/2)*vds*ids=Pturb*/
			
		/*	vds= ZONE (ids<0) -Pturb/(1.5*ids)
				  OTHERS 0*/
			/*
			Lqs*iqs'=ZONE (iqsx>0) -0.00001
						OTHERS iqsx
			
			iqsx=-vqs-Rs*iqs+(p*wt)*Lds*ids+(p*wt)*phi*/
			
	--		Lqs*iqs'=-vqs-Rs*iqs+(p*wt)*Lds*ids+(p*wt)*phi
				
	-- Considerando que los voltajes en coordenadas abc sean balanceados, se cumple:
	-- a) El voltaje del eje d es una constante que es igual al valor mximo de los voltajes abc
	-- b) Los voltajes de los ejes q y 0 son ambos cero
	
	--		Vm=vds   -- Voltage pico de salida del Generador
			
				
		
	-- Definicion de los voltajes del aerogenerador en cada fase
	
	
	/*
			turbineav.Vma= ZONE (Vm>=362.757) 362.757
			               ZONE (Vm<=0) 0
			               OTHERS Vm  			      	-- Va= Vm cos(wt*p*TIME)*/
			               
			--turbinebv.Vma=Vm			-- Vb= Vm cos(wt*p*TIME - 2*pi/3)
			--turbinecv.Vma=Vm			-- Vc= Vm cos(wt*p*TIME + 2*pi/3)
			
			-- Corriente pico de la salida del aerogenerador fijada por el distribuidor		
			
	/*		ids=-Im-0.0001
			
			Im=turbineai.Ima
			
			Pgen=(3/2)*vds*ids+(3/2)*vqs*iqs			
			  	
			
END COMPONENT


--------------------------------------------------------------------------------
--                        COMPONENTE DEL RETIFICADOR 
--------------------------------------------------------------------------------


COMPONENT RECTIFIER

PORTS


 -- Conexion Windy Turbine - Rectificador
	 IN WindrectV      	distrectv 
    OUT WindrectI     	distrecti
  
  -- Conexion rectificador - Windy Boy
  
    OUT rectWBV      	rectv
    IN rectWBI      		recti

	
DATA

-- Datos del Rectifcador

	REAL Rprot=30					"Reisistencia de Proteccion (ohmios)"
	REAL frect=0.997				"Constante auxiliar"  --REVISAR


CONTINUOUS


-- Voltaje de Salida del rectificador
	
	/*	
			Vdcx= ZONE (Vdcinv<=Vdcmin) Vdcmin
				    ZONE (Vdcinv>=Vdcmax) Vdcmax
				    OTHERS Vdcinv
		*/
	
   	--	rectv.Vdc=1.654*distrectv.Vma
	
	-- Corriente que sale del rectificador fijada por el inversor 
	
	--		distrecti.Ima=recti.Idc/(frect*0.90689)
		
	--		Idc = Idcinv --ZONE (Vdcinv>600) Idcinv+(Vdcinv/Rprot) 
			
					--OTHERS Idcinv*/	

/*
END COMPONENT


--------------------------------------------------------------------------------
--                       COMPONENTE DEL WINDY BOY 
--------------------------------------------------------------------------------

	COMPONENT WINDYBOY  
   
	PORTS
	
	-- Conexion rectificador - Windy Boy
	
	   IN rectWBV      		rectbv
      OUT rectWBI      		rectbi
      
   -- Conexion Windy Boy - Sunny Island  
      
      OUT SBSII				wbi
      IN SBSIV					wbv
		
		
		
DATA
	
-- Datos del Inversor	
	
	REAL Vdcmin=246				"Voltaje mnimo del inversor (Volts)"
	REAL Vdcmax=600				"Voltaje mximo del inversor (Volts)"
	REAL Idcmax=26					"Coriente mxima que acepta el Windy Boy (Amps)"
	REAL k3=10						"Constante auxiliar"   --REVISAR
   REAL k1=5						"Constante auxiliar"   --REVISAR
   REAL eff=1						"Porcentaje de potencia del inversor"
   REAL Va=260						"Voltaje a para limitar la potencia (Volts)"
   
   
DECLS 

-- Variables del Inversor
	
	REAL Ipinv						"Corriente pico a la salida del inversor (Amps)"
	REAL Vpinv 						"Voltaje pico a la salida del inversor (Amps)"
	REAL Pinv						"Potencia del inversor (W)"
	EXPL REAL  ninv				"Eficiencia del inversor"
	REAL Idcinv						"Variable auxiliar corriente dc del inversor"
	EXPL REAL Vrect				"Voltaje DC del rectificador (Volts)"
	REAL Irect						"Corriente DC al rectificador (Amps)"
	REAL effwb						"Porcentaje de potencia del inversor"
	REAL fac
	REAL Vb							"Voltaje b para limitar la potencia (Volts)"
	REAL Potref						"Potencia de Referencia"
	REAL PotLim
	REAL Ib
	


	INIT
		
  		Idcinv=6.9767
  		
  	DISCRETE

       WHEN (effwb!=1)THEN
 				Potref=Pinv --100000--Psb 
       END WHEN
       
       WHEN (effwb==1)THEN
 				Potref=6000  
       END WHEN       
       
   CONTINUOUS 
   
         fac= wbv.fac 
    		
			effwb = ZONE ((fac>=45.5) AND (fac<=51)) 1
				  ZONE ((fac>=51) AND (fac<=52))  (-fac+52)
				  OTHERS 0              -- se tiene que apagar el sunny island
		   
		   PotLim= effwb*Potref
				  	
		
		-- Calculo de la Corriente que el inversor le tiene que pedir al rectificador 
		
		-- Si effsb=1, potencia mxima se tiene que Vb=600	-- Estos valores se programan en WB
		-- Si effsb=0, potencia 0, se tiene que Vb=246 -- Estos valores se programan en WB
		-- Si effsb=0.5, potencia media, se tiene que Vb=423  -- Estos valores se programan en WB	
		
		   Vb=(PotLim+4588.235)/(17.647)
		   
		   Ib=PotLim/Vb
							   
		   Vrect=rectbv.Vdc
		   
			
			/*Idcinv'=ZONE (eff==0) -k3*Idcinv
					  OTHERS k1*(Vb-Vrect)--*(Idcmax-Idcinv)/Idcmax*/
					  
			/*Idcinv'=ZONE (Vrect>Vb) -k1
			        ZONE (Vrect==Vb) 0
					  OTHERS k1	  
			
			Irect= ZONE (Idcinv<0) 0
				    ZONE (Idcinv>Idcmax) Idcmax
				    OTHERS Idcinv
							
			rectbi.Idc= Irect
			
				/*	
			-- Calculo de la Potencia a la salida del inversor 

  			ninv=0.96
      
   		Pinv= ninv*Irect*Vrect 
   		
   		Vpinv= wbv.Vmb 
   		
			-- Calculo de la corriente pico de la salida del inversor 
			-- Pinv es la potencia por cadav lnea que destina el distribuidor de potencia
         				
			--Ipinv=(2*Pinv)/(Vpinv)	
			
			-- Sin distribuidor de potencia se tiene que:
			Ipinv=(2*Pinv)/(3*Vpinv)
			
			wbi.Imb=Ipinv 
		
	
	END COMPONENT		
	
	
	// a) Leer el manual verificar info
	// b) Dejar parametros anteriores cambiar a la nueva configuracion
	// c) Cambios de frecuencia
	// d) Nuevo modelo para el CP
	// e) Cambiar parametros*/
	
	
	/*
COMPONENT turbina

PORTS


    -- Conexion Windy Turbine - Rectificador
       OUT WindrectV      turbineav 
    --   OUT WindrectV      turbinebv
    --   OUT WindrectV      turbinecv
       IN WindrectI       turbineai
     --  IN WindrectI       turbinebi
     --  IN WindrectI       turbineci
       
           	
DATA


TABLE_1D Tabve = {{0.5,1.5,2.5,3.5,4.5,5.5,6.5,7.5,8.5,9.5,10.5,11.5,12.5,13.5,14.5,15.5,16.5,17.5,18.5,19.5,20.5,21.5,22.5,23.5},

            {6,6.4,7.32,5.45,5.57,4.38,4.62,4.95,5,4.63,4.6,6.067,5.68,5.03,4.95,5.01,5.183,4.7833,4.716,4.4166,5.45,4.7166,4.166,4.6833}}
	
TABLE_1D Tabgrados = {{0.5,1.5,2.5,3.5,4.5,5.5,6.5,7.5,8.5,9.5,10.5,11.5,12.5,13.5,14.5,15.5,16.5,17.5,18.5,19.5,20.5,21.5,22.5,23.5},

            {241.83,249.5,251.833,246.166,250.833,244.66,229.166,230.666,221.333,219,240.33,260.33,268,264.16,266.833,277.5,284.5,264.66,272.5,260.83,258.5,246.5,222.66,221}}
	
-- Entradas
	
	REAL ve=8						"Velocidad del viento (m/seg)"
	REAL grado = 241.83			    "Direccin del viento (Grados)"

-- Datos de la Turbina

	REAL r=4.5						"Radio de la turbina (m)"
	REAL Mt=1100					"Masa de toda la turbina, incluyendo el generador (Kg)"
	REAL Cf=15						"Constante del modelo de Cp"
	REAL Ro=240						"Angulo de posicion de la turbina (degrees)"  --REVISAR

-- Datos del Generador

	REAL p=12							"Nmero de par de polos del generador"
	
	-- Falta revisar
	REAL Ls=0.074					"Inductancia del generador (H)"
	REAL Rs=5.2						"Resistencia del estator (ohmios)"
	REAL phi=1.1 			   	    "Flujo magnetico"  --Revisar
	REAL Fr=10						"constante de proporcionalidad de la fuerza de Roce"

-- Datos de Beta

	REAL Bmax=25					"Angulo de pitch mximo (C)"	
	REAL Bmin=0						"Angulo de pitch minimo (C)"
	REAL deltaBmax=6					"Variacin mxima del angulo de pitch (C/seg)"
	REAL deltaBmin=-6					"Variacin mnima del angulo de pitch (C/seg)"
	REAL Tservo=0.5					"Retraso para la seal Bref (seg)"

-- Constantes

	REAL denso=1.2256				"Densidad del aire (kg/m3)"	
				
DECLS

-- Variables de Entradas
	   
	--EXPL REAL ve					"Velocidad del viento (m/seg)"
	--EXPL REAL grado				"Direccin del viento (degrees)"
	
-- Variables de la Turbina

	EXPL REAL  Pviento			"Potencia del viento (W)"
	EXPL REAL  Lamda				"Relacion entre la velocidad lineal de las paletas y el viento"
	EXPL REAL  Beta				"Angulo de inclinacion"	
	REAL Cwt
	EXPL REAL  Pturb				"Potencia que se genera en la turbina (W)"
	REAL Cp							"Coeficiente de Potencia"
	REAL Cpx							"Coeficiente de Potencia"

-- Variables del Generador
	
	EXPL REAL  Jt					"Constante de inercia de la turbina"   --Revisar
	REAL wt							"Velocidad angular de la turbina de viento (rad/seg)" 
	EXPL REAL ids					"Corriente del estator del generador en el eje d (Amps)"
	REAL iqs, iqsx					"Corriente del estator del generador en el eje q (Amps)"
	REAL vds						"Voltaje del estator en el eje d- directo (Volts)"
	REAL vqs						"Voltaje del estator en el eje de cuadratura - q (Volts)"
	REAL Pgen						"Potencia del Generador (W)"
	REAL Im							"Corriente pico del generador (Amps)"
	REAL Vm							"Voltaje pico del Generador (Volts)"
	
	 		
INIT
	 	wt = 10
     	iqs = 0
  		vqs=0
      
CONTINUOUS

--                  DATOS DE ENTRADA
----------------------------------------------------------------------------

		
-- Definir la direccion y velocidad del viento en funcion del tiempo

		--	ve = timeTableInterp(TIME,Tabve)
			
		--	grado = timeTableInterp(TIME,Tabgrados)
			
			
--                  Potencia del Viento
----------------------------------------------------------------------------
 		
	  		Pviento=denso*PI*(r**2)*(ve**3)/2
	  

--                  ACTUADOR DEL PITCH ANGLE
----------------------------------------------------------------------------
	  			  		
	  		deltaBx=Bref-B
	  		
	  		deltaB= ZONE (deltaBx>=deltaBmax) deltaBmax
	  		        ZONE (deltaBx<=deltaBmin) deltaBmin
	  		        OTHERS deltaBx
	  		        	  		
	  		Bx'=deltaB/Tservo
	  		
	  		B= ZONE (Bx>=Bmax) Bmax
	  		   ZONE (Bx<=Bmin) Bmin
	  		   OTHERS Bx
	  		         
--                  Coeficiente de Potencia
----------------------------------------------------------------------------
	  		
			Lamda=wt*r/ve	  		
	  		
	  		Cp= ZONE (Cpx<0) 0
				 OTHERS Cpx
			
			Cpx= ZONE (Lamda<=1) 0
				  OTHERS (1/2)*((r*Cf/Lamda)-0.322*Beta-2)*exp(-0.255*(r*Cf/Lamda))	  		

						  			  		
--                  Potencia de la Turbina
----------------------------------------------------------------------------

	  		Pturb=Cp*Pviento


--                  MODELO MECANICO ENTRE TURBINA Y GENERADOR
----------------------------------------------------------------------------	  		
	  		 		
	  		-- Suma del momento de inercia de la turbina y del generador 		
			Jt=1--(1/2)*Mt*(r**2)  
						     		
			(Jt)*wt'=(((Cp*Pviento)/wt)+(3*p*(phi*iqs)/2)-Fr*wt)		
				

--                 MODELO ELECTRICO DEL GENERADOR
----------------------------------------------------------------------------

			Ls*ids'=vds-Rs*ids+Ls*(p*wt)*iqs	  
			
			Ls*iqs'=vqs-Rs*iqs-Ls*(p*wt)*ids-(p*wt)*phi
			
			
END COMPONENT


			
--******************************************************************************
--                  Modelo del Inversor
--******************************************************************************

--                  Tensin del bus de continua(Vdc) 
----------------------------------------------------------------------------
         
		-- Revisar lo de los 3/2 que multiplica a las potencias         
              
      C*Vdc*Vdc'=(3/2)*((vds*ids)+(vqs*iqs)-(vdr*idr)-(vqr*iqr))
      
      

--                       Calculo del Inversor VCS
----------------------------------------------------------------------------
   

--                           Modelo de la red
----------------------------------------------------------------------------
-- Se calcula ia,ib e ic
-- ua,ub y uc me lo da el PWM
-- ea, eb y ec me lo da la red
     
      Ln*iar'=(-Rr*iar)+(ua-ea)
      
      Ln*ibr'=(-Rr*ibr)+(ub-eb)
      
      Ln*icr'=(-Rr*icr)+(uc-ec)
          
----------------------------------------------------------------------------			
			
			
--******************************************************************************
--                  Control de Alto nivel
--******************************************************************************


wtref= ZONE (wt<=wtmin) wtmin
	 ZONE ((wt>wtmin) AND (wt<=wtnom)) lamdaopt*ve/r
	 ZONE ((wt==wtnom) AND (Pmec<Pmecnom)) wtnom
	 OTHERS wtnom


--                  Controlador de Bref
----------------------------------------------------------------------------

deltawt=wtref-wt
    
Brefx'=(kpz*deltawt')+kiz*deltawt


-- Falta incluir lo de Gain scheduling para tener control no lineal, cambios en tiempo de kpz y kiz


Bref= ZONE(ve>venom) Brefx    -- Limitacin
      OTHEERS 0		      -- Optimizacin



--           Controlador del Torque de referencia Tgenrefx
----------------------------------------------------------------------------



       
 


--                  Efecto Droop
----------------------------------------------------------------------------
   
	-- Tgenrefx viene de la diferencia entre wt
	-- No se quien es Fref
	-- Fred la tomo de la red
	   
   
   deltafx=Fref-Fred
   
   -- OJO Falta definir deltaf  
   
   deltaP=Kfrec*deltaf
   
   deltaTgen=deltaP/(p*wt)         --Par de la maquina
   
   Tgenrefy=Tgenrefx-deltaTgen
   
   Tgenref= ZONE (Tgenrefy>=Tgenmax) Tgenmax
            ZONE (Tgenrefy<=Tgenmin) Tgenmin
            OTHERS Tgenrefy

     
--                  Calculo de ids_ref y iqs_ref
----------------------------------------------------------------------------
   
   -- ids_ref
   
   iqs_ref=-2*Tgenref/(3*p*phi)
   
--                  Calculo de idr_ref y iqr_ref
----------------------------------------------------------------------------

	iqr_ref=0  -- Para que slo se envie potencia activa
	
	-- idr_ref= FALTA OJO
----------------------------------------------------------------------------



--******************************************************************************
--                  Control Convertidor Lado Rotor
--******************************************************************************

-- ids_ref, iqs_ref lo entrega el control de Alto nivel
-- iqs, ids, wt lo tomamos del generador
   
--                  Calculo de udr_ref y uqr_ref
----------------------------------------------------------------------------
	
	deltaids=ids_ref-ids
	
	uds_aux'=Kpc*deltaids'+Kic*deltaids	
	
	uds_ref=uds_aux-Ls*(p*wt)*iqs

	deltaiqs=iqs_ref-iqs
	
	uqs_aux'=Kpd*deltaiqs'+Kid*deltaiqs
	
	uqs_ref=uqs_aux+Ls*(p*wt)*ids+(p*wt)*phi

--------------------------------------------------------------------------------


--******************************************************************************
--                  Control Convertidor Lado Red
--******************************************************************************
-- idr, iqr me la entrega el modelo de la red
-- idr_ref, iqr_ref me la entrega control de alto nivel
-- ea, eb, ec y wr es el valor del Voltaje en el PCC 
 
 
--                   Voltaje medido en la red
----------------------------------------------------------------------------
 -- ea=E*cos(wr*t)
 -- eb=E*cos(wr*t-2PI/3)
 -- ec=E*cos(wr*t+2PI/3)
  
 -- Pasamos de tres fases a dos fase

    eas=ea+(eb/2)-(ec/2)
   
    ebs=(0*ea)+(sqrt(3)*eb/2)-(sqrt(3)*ec/2)
 
 -- Pasamos de dos fases a las coordenadas d-q
 
 	ed=eas*cos(wr*t)+ebs*sin(wr*t)
 
 	eq=ebs*cos(wr*t)-eas*sin(wr*t)
 	
 	-- Verifcar para sistema balanceado queda ed=E y es=0 OJO OJO OJO
   
   
--                  Calculo de udr_ref y uqr_ref
----------------------------------------------------------------------------
  
	deltaidr=idr_ref-idr
	
	udr_aux'=Kpa*deltaidr'+Kia*deltaidr
	
	udr_ref=udr_aux-(wr*Lr*iqr)+ed
	
	deltaiqr=iqr_ref-iqr
	
	uqr_aux'=Kpb*deltaiqr'+Kib*deltaiqr
	
	uqr_ref=uqr_aux+(wr*Lr*idr)+eq
	
-------------------------------------------------------------------------


		*/
		
		/*
		-- Definicion de la corriente

	Ia=ids*cos(p*wt*TIME)-ids*sin(p*wt*TIME)

	Ib=ids*cos((p*wt*TIME)-(2*PI/3))-iqs*sin((p*wt*TIME)-(2*PI/3))

	Ic=ids*cos((p*wt*TIME)+(2*PI/3))-iqs*sin((p*wt*TIME)+(2*PI/3))

	Idc=(Sa*Ia)+(Sb*Ib)+(Sc*Ic) 

	GSCDClinkIa.Idc=Idc
				
-- Definicin del Voltaje (REVISAR OJO)

	Uan=(Udc/3)*((2*Sa)-Sb-Sc)

	Ubn=(Udc/3)*(-Sa+(2*Sb)-Sc)

	Ucn=(Udc/3)*(-Sa-Sb+(2*Sc))

	vds=(2/3)*((Uan*cos(p*wt*TIME))+(Ubn*cos((p*wt*TIME)-(2*PI/3)))+(Ucn*cos((p*wt*TIME)+(2*PI/3))))

	vqs=-(2/3)*((Uan*sin(p*wt*TIME))+(Ubn*sin((p*wt*TIME)-(2*PI/3)))+(Ucn*sin((p*wt*TIME)+(2*PI/3))))

	vo=(Uan+Ubn+Ucn)/3*/
	
	
	/*			
	
		  	 		
		-- Se calcula vs1, vs2 y vs3 en funcion del voltaje del rectificador
		  	
		  	vs1=1/3*(2*Vrect13-Vrect23)
		  	vs2=1/3*(-Vrect13+2*Vrect23)
		  	vs3=1/3*(-Vrect13-Vrect23)
		  	
		-- Se calcula vds y vqs
		  	
		  	vds=2/3*(vs1*cos(theta)+vs2*cos(theta-120)+vs3*cos(theta-240))
		  	
		  	vqs=-2/3*(vs1*sin(theta)+vs2*sin(theta-120)+vs3*sin(theta-240))
		  	

----------------------------------------------------------------------------
--             CONTROLADOR 
----------------------------------------------------------------------------

// a.- PRIMER LAZO - MODELO DEL RECTIFICADOR PWM
		  	
	
	// Se utiliza para rectificar el voltaje proveniente del capacitor
	// se utiliza para rectificar la corriente proveniente del generador		
		  	
		  	Vrect13=(Srec11-Srec31)*Ucap
		  	Vrect23=(Srec21-Srec31)*Ucap
		  	
		  	Irect=(Srec11-Srec31)*ids+(Srec21-Srec31)*iqs


	
// c.- PUNTO CENTRAL - Calculo del voltaje del capacitor		

// Si Id aumenta, Ucap aumenta, Iinv tiene que aumentar hasta que Ucap const
// Si Id disminuye, Ucap dimsinuye, Iinv tiene que disminuir hasta que Ucap const  	
		  	
		  	Ccap*Ucap'=Irect-Iinv	 		
		  	  	
-----------------------------------------------------------------------------

 ----------------------------------------------------------------------------------------------
 Vref=(PotLim+4588.235)/(17.647)  // Valor del voltaje DC de referencia en funcin del voltaje de salida
 
 Potdcref=PotLim/ninv  // Valor de la potencia DC de referencia
 
 Iref=Potdcref/Vref  // Valor de la corriente DC de referencia
 
 ------------------------------------------------------------------------------------------------
 
 
 Potsalida=(Ucap*17.647)-4588.235  // Potencia de salida que corresponde con el Ucap
 
 Potdcreal=Potsalida/ninv  // Potencia de entrada dc que corresponde con el Ucap
 
 Ireal=Potdcreal/Ucap // Corriente que corresponde con ese valor de Ucap
 
 -----------------------------------------------------------------------------------------------

		*/
			