USE MATH

--*************************************************************************

--*************************************************************************
-- Solar

COMPONENT Solar

-- El objetivo del presente modulo es la modulacion de arreglo solar
-- sus resultados estarn incluidos en el resto de la simulacion
-- Module Used: Wuxi Green Energy Source - 185Wp

-- PRUEBA 1
-- Con el modulo Arreglo Solar se determino el MPP para G=1000 y Tenv=25
-- P=4284.59304
-- I=17.0658312
-- V=251.062663

PORTS

----------------------------------------------------------------------------
-- Relacion PV Array - Boost converter
----------------------------------------------------------------------------

   	IN PVCV  		pvcva    -- Voltaje de entrada fijado por el boost converter
   	OUT PVCI  		pvcia    -- Corriente resultante del modulo
   	
---------------------------------------------------------------------------
--                  Reference Voltage Defined - PV Solar
----------------------------------------------------------------------------

		OUT  RVDPVS  			RVDPVSb   	
   	
 /*
----------------------------------------------------------------------------
-- Relacion PV array - MPPT Tracking
----------------------------------------------------------------------------

		OUT PVMPPTI  		pvmpptia    -- Corriente del arreglo solar
		OUT PVMPPTV  		pvmpptva     -- Voltaje del arreglo solar
*/
----------------------------------------------------------------------------		
-- Relacion PV array - Boost controller
----------------------------------------------------------------------------
		
		OUT PVBCV 			pvbcva     -- Voltaje del arreglo solar
     	
DATA


-- Module Used: Wuxi Green Energy Source - 185Wp

   REAL Vocmstc=44.8 		" Open Circuit voltage - Module (Volts)"
	REAL Iscmstc=5.51			" Short Circuit current - Module (Amps)"
	REAL NOCT=46				" Normal operating cell temperature (C)"
	REAL Vmpmstc=36.2			" Voltage at maximum power - Module (Volts)"
	REAL Impmstc=5.11			" Current at maximum power - Module (Amps)"
	REAL Pmaxmstc=185 		" Maximun Power - Module (Wp)"
	REAL Tref=25				" Reference temperature  (C)"
	REAL Gstc=1000				" Standard solar radiation (w/m2)"
	REAL Beta=-0.38			" Sensitivity of Open Circuit voltage to temperature (%/C)"
	REAL Alfa=0.10				" Sensitivity of Short Circuit current to temperature (%/C)"
	REAL Gamma=-0.47			" Sensitivity of Maximun Power to temperature (%/C)"
	REAL Surface = 1.277 	" Module surface (m2)"
	REAL Nsc=12					" Number of cells in series within the PV module (--)"
	REAL Npc=6 					" Number of cells in parallel within the PV module (--)"
	REAL Efficiency=14.8		" Modules efficiency (%)"
	
-- Datos Suministrado por el diseo del Arreglo Fotovoltaico
	
	INTEGER Npm = 3			" Number of modules in parallel (--)"
	INTEGER Nsm = 9			" Number of modules in series (--)"
	
	
-- Constantes

	REAL vt = 0.0248			" Thermal voltage (volts)"

-- Valores Geogrficos
	
	REAL G=1000					" Solar radiation (w/m2)"
	REAL Tenv=25 				" Environment temperature (C)"  
   
DECLS
	
	EXPL REAL Tcell				" Cell temperature  (C)"
	EXPL REAL Vocg 				" Open circuit voltaje - Array (Volts)"
	EXPL REAL Iscg 				" Short circuit current - Array (Amps)"
	EXPL REAL Voc					" Open Circuit Voltage of a cell (Volts)"	
	EXPL REAL Vocn				   " Open Circuit Voltage of a cell normalizado"	
	EXPL REAL Isc					" Short Circuit Current of a cell (Amps)"	
	EXPL REAL Pmax				   " Maximum Power of a cell (Wp)"	
	EXPL REAL FF					" Factor de Forma STC para una celda solar"	
	EXPL REAL FFo					" Factor de Forma STC para una celda ideal"	
	EXPL REAL rs					" Series resistance of a cell normalizada"	
	EXPL REAL Rsm					" Series resistance of a module (Ohms)"	
	EXPL REAL Rsg					" Series resistance - array (Ohms)"
	EXPL REAL Vdcpv				" Output Voltage DC definido por el condensador(Volts)"
	REAL Idcpv						" Output Current respuesta del panel solar al estimulo del condensador (Amps)"
	

INIT
    	     
CONTINUOUS

 
-------------------- Calcular Resistencia en serie de un arreglo solar-------------------------

-- a) Caractersticas de una celda solar:
		Voc=Vocmstc/Nsc
		Vocn=Voc/vt
		Isc=Iscmstc/Npc
		Pmax=Pmaxmstc/(Npc*Nsc)
	
-- b) Factor de Forma STC para una celda solar:
		FF=Pmax/(Isc*Voc)					
		
-- c) Factor de forma para una celda ideal sin considerar la resistencia serie:
		FFo=(Vocn-log(Vocn+0.72))/(Vocn+1)
		
-- d) Resistencia en serie de una celda solar normalizada:
		rs =1-(FF/FFo)					

-- e) Resistencia en serie de un modulo solar:
		Rsm=rs*Vocmstc/Iscmstc    	

-- f) Resistencia en serie de un arreglo solar:		
		Rsg=Rsm*Nsm/Npm 

	-- Temperatura de Trabajo
	
	Tcell=Tenv+(G*(NOCT-20)/800)
	
	-- Voltaje a circuito abierto 	
			
	Vocg=Nsm*Vocmstc*(1+ (Beta*(Tcell-Tref)/100))
	
	-- Corriente a Corto Circuito 
	
	Iscg= Npm*Iscmstc * G * (1 + (Alfa*(Tcell - Tref)/100))/ Gstc 
	   	
	-- Calculo la corriente considerando el voltaje impuesto por el condensador
	
	Vdcpv=pvcva.Vdc 
	
	-- Limitacion del voltaje de entrada, no puede ser mayor al VOC
	   
   Idcpv=Iscg*(1-exp((Vdcpv+Rsg*Idcpv-Vocg)/(vt*Nsm*Nsc)))

	pvcia.Idc=Idcpv 
	
	RVDPVSb.Idc=Idcpv 
	
	RVDPVSb.Vdc=Vdcpv
	
	pvbcva.Vdc=Vdcpv
	
END COMPONENT

 
--*************************************************************************

--*************************************************************************
-- Boost Converter 

COMPONENT BoostConverter

-- El objetivo del presente modulo es la modulacion del cirtuito Boost
-- sus resultados estarn incluidos en el resto de la simulacion


PORTS

-- relacion Boost con el arreglo solar

   	OUT PVCV  		pvcvb    -- Voltaje de entrada fijado por el boost converter
   	IN PVCI  		pvcib    -- Corriente resultante del modulo
   	
-- relacion Boost con el Sunny Boy

		//IN CSBV  		csbva    -- Voltaje de entrada fijado por el Sunny Boy
   	//OUT CSBI  		csbia    -- Corriente dirigida al Sunny boy

-- relacion Boost Circuit con DCLink

		OUT GSCDClinkI					GSCDClinkIf				-- Salida Igsc
		IN GSCDClinkV					GSCDClinkVf				-- Entrada Udc   	

-- relacion Boost con el PWM

		IN CPWMS  		cpwmsa    -- Modulador del Boost circuit
			
DATA

		REAL Cpv=0.0000000005		"Capacitance (F)"
		REAL R=0.5						"Resistance (ohm)"
		REAL L=0.000120				"Inductance (H)"
		 
   
DECLS
	
		REAL Idcpv					"Corriente dc del Arreglo Solar (Amps)"
		REAL Vdcpv					"Volatje dc del Arreglo Solar (Volts)"
		REAL IL						"Corriente en el inductor L (Amps)"
		REAL Vboost					"Voltaje resultante de la modulacion Boost (Volts)"
		REAL Iboost					"Corriente resultante de la modulacion Boost (Amps)"
		REAL s						"Indice de modulacion"
		REAL Vdc						"Voltaje del condensador de salida (Volts)"
		
INIT
    	     
CONTINUOUS

-- Entrada: corriente proveniente del arreglo solar
	Idcpv=pvcib.Idc 
	
	
-- Entrada: Voltaje de entrada fijado por el Sunny Boy	
	//Vdc=csbva.Vdc   

-- Entrada: Voltaje de entrada fijado por el DCLink		
	Vdc=GSCDClinkVf.Udc
	
	
-- Entrada: Modulacion del PWM 
	s=cpwmsa.s


-- Ecuacion del BJT
-- Entrada Vdc
	Vboost= s*Vdc
	
-- Ecuacion del Condensador Cpv
		-- Entrada: Idcpv, IL	
		-- Salida: Vdcpv
	Cpv*Vdcpv'=Idcpv-IL

-- Ecuacion del Inductor L
	Vdcpv-(R*IL)-(L*IL')=Vboost
			
-- Ecuacion del BJT
-- Salida Iboost		
	Iboost=s*IL

-- Salida: Corriente dirigida al Sunny boy	
//	csbia.Idc=Iboost 

-- Salida: Corriente dirigida al DCLink	
	GSCDClinkIf.Idc=Iboost
	
-- Salida: Voltaje del arreglo solar
	pvcvb.Vdc=Vdcpv
  	   
 
END COMPONENT

--*************************************************************************

--*************************************************************************
-- Sunny Boy

-- Solo es un modulo de Prueba para verificar la modulacion a voltage
-- DC Link constante
 
COMPONENT SunnyBoy

-- El objetivo del presente modulo es la modulacion del Sunny Boy
-- sus resultados estarn incluidos en el resto de la simulacion

PORTS
  	
-- relacion Boost con el Sunny Boy

		OUT CSBV  		csbvb    -- Voltaje de entrada fijado por el Sunny Boy
   	IN CSBI  		csbib    -- Corriente dirigida al Sunny boy
DATA
   
   REAL Vdc=500			"Output Capacitor Voltage (Volts)"
   
DECLS
		
	REAL Iboost 			"Corriente de salida del Boost circuit (Amps)"
	
INIT
    	     
CONTINUOUS

-- Entrada: corriente proveniente del Boost circuit
	Iboost=csbib.Idc 
		
-- Salida: Voltaje fijado por el sunny boy
	csbvb.Vdc=Vdc	   
 
END COMPONENT

