USE MATH

-- El presente codigo se utiliza para el modelado
-- del Windy Boy y Sunny Boy asumiendo que ambos
-- Tienen comportamiento similares
-- Fecha de Actualizacion: 09/07/2010


COMPONENT DCLink 

PORTS

---------------------------------------------------------------------------
--        DCLink - (Wind Turbine or PV Array)
----------------------------------------------------------------------------
		
		IN GSCDClinkI					GSCDClinkIb				-- Entrada Igsc
		OUT GSCDClinkV					GSCDClinkVb				-- Salida Udc
		

---------------------------------------------------------------------------
--        DCLink - Grid Side Converter
----------------------------------------------------------------------------		

		IN GrdSCDClinkI					GrdSCDClinkIa				-- Entrada Igrdsc
		OUT GrdSCDClinkV					GrdSCDClinkVa				-- Salida Udc
		
---------------------------------------------------------------------------
--        Grid Side Controller - DCLink
----------------------------------------------------------------------------

		OUT GSCDClinktV			GrdSCDClinktVb				
		                	
DATA

	REAL C						"Capacitancia del condensador dek enlace DC"

DECLS

	REAL Idc						"Corriente DC de Wind Turbine or PV array (Amps)"
	REAL Igrdsc					"Corriente DC de Grid Side Converter (Amps)"
	REAL Udc						"Output Voltage DC-Link (Volts)"

INIT
	 
CONTINUOUS

		Idc=GSCDClinkIb.Idc
		Igrdsc=GrdSCDClinkIa.Igrdsc

		
		C*Udc'=Idc-Igrdsc

		GSCDClinkVb.Udc=Udc
		GrdSCDClinkVa.Udc=Udc
		GrdSCDClinktVb.Udc=Udc
		
END COMPONENT


--*************************************************************************

--*************************************************************************

-- Grid Side Converter 

COMPONENT GridSideConverter

PORTS


---------------------------------------------------------------------------
--        Grid Side Coverter  - AC Line Filter
----------------------------------------------------------------------------
		
		IN GrdSCFilterI				GrdSCFilterIa 				-- Entrada Ifilter
		OUT GrdSCFilterV 				GrdSCFilterVa				-- Salida Uinv
 	
---------------------------------------------------------------------------
--        Grid Side Converter  - DC-LINK
----------------------------------------------------------------------------
   	
		OUT GrdSCDClinkI					GrdSCDClinkIb				-- Salida Igrdsc
		IN GrdSCDClinkV					GrdSCDClinkVb				-- Entrada Udc
		
---------------------------------------------------------------------------
--        Grid Side Converter - PWM (Spce Vector Modulation)
----------------------------------------------------------------------------
    
     IN GrdSCPWM					 GrdSCPWMa
           	
DATA

				
DECLS	

		REAL Ifilter				"Output Current AC Line Filter (Amps)"
		REAL Udc					"Output voltage DC Link (Volts)"
		REAL S1					"Switch Q1 single phase inverter"
		REAL S3					"Switch Q2 single phase inverter"
		REAL Igrdsc				"current DC from Single Phase Inverter"
		REAL Uinv				"Output Voltage Single phase inverter (Volts)"
		 		
INIT
	 	
CONTINUOUS

Ifilter=GrdSCFilterIa.Ifilter
Udc=GrdSCDClinkVb.Udc
S1=GrdSCPWMa.S1
S3=GrdSCPWMa.S3

SEQUENTIAL

	IF ((S1==1) AND (S3==0)) THEN
	Uinv=Udc
	
	ELSEIF ((S1==0) AND (S3==1)) THEN
	Uinv=-Udc
	
	ELSE 
	Uinv=0
	
	END IF
		
END SEQUENTIAL

Igrdsc= Uinv*Ifilter/Udc

GrdSCDClinkIb.Igrdsc=Igrdsc
GrdSCFilterVa.Uinv=Uinv

END COMPONENT 

--*************************************************************************

--*************************************************************************

-- AC Line Filter

COMPONENT ACLineFilter

PORTS

---------------------------------------------------------------------------
--        Grid Side Coverter  - AC Line Filter
----------------------------------------------------------------------------
		
		OUT GrdSCFilterI				GrdSCFilterIb 				-- Salida Ifilter
		IN GrdSCFilterV 				GrdSCFilterVb				-- Entrada Salida Uinv

---------------------------------------------------------------------------
--        AC Line Filter - TRansformer
----------------------------------------------------------------------------
 	
 		OUT FilterTRansI				FilterTRansIa 				-- Salida Ifilter
		IN FilterTRansV 				FilterTRansVa				-- Entrada Salida Uinv
 	
 		
DATA

		REAL La				"Inductance Filter A"
		REAL Lb				"Inductance Filter B"
		REAL C				"Capacitance Filter"
	
				
DECLS	
		
		REAL Uinv			"Output Voltage Single Phase Inverte (Volts)"
		REAL UTRans			"Input Volage TRansformer (Volts)"
		REAL ITRans			"TRasformer Current (Amps)"
		REAL Ifilter		"Filter Current (Amps)"
		REAL Uf				"Capacitor Voltage (Volts)"
				 		
INIT
	 	
CONTINUOUS

-- Entradas
	
	Uinv=GrdSCFilterVb.Uinv
	
	UTRans=FilterTRansVa.UTRans

-- COdigo
	
	Uinv=La*Ifilter'+Uf
	
	Uf=Lb*ITRans'+UTRans
	
	C*Uf'=Ifilter-ITRans
	
-- Salida	
	
	FilterTRansIa.ITRans=ITRans
	
	GrdSCFilterIb.Ifilter=Ifilter
	
END COMPONENT 


